@@ -80,8 +80,7 @@ class SFTPConnector(object):
                     transport.close()
         return pathsuffix
 
-    def download_files(self, local_path, project_name, exprement_id):
-        remote_path = "/" + project_name + "/" + exprement_id + "/"
+    def download_files(self, local_path, remote_path):
 
         self.ssh.connect(self.host, self.port, self.username, password = self.password)
         with SCPClient(self.ssh.get_transport()) as conn:
